@@ -1,4 +1,4 @@
-### whiten.R  (2020-12-05)
+### whiten.R  (2022-05-29)
 ###
 ###    Whitening data matrix
 ###
@@ -24,7 +24,10 @@
 
 
 # whiten data using empirical covariance matrix
-whiten = function(X, center=FALSE, method=c("ZCA", "ZCA-cor", "PCA", "PCA-cor", "Chol-prec", "Chol-cov", "Cholesky"))
+whiten = function(X, center=FALSE, 
+     method=c("ZCA", "ZCA-cor", 
+              "PCA", "PCA-cor", 
+              "Cholesky"))
 {
     method = match.arg(method)
 
@@ -34,5 +37,9 @@ whiten = function(X, center=FALSE, method=c("ZCA", "ZCA-cor", "PCA", "PCA-cor",
 
     if(center) Z = sweep(Z, 2, colMeans(Z))
 
+    colnames(Z) = paste0("L", 1:ncol(X))
+
+    attr(Z, "method") = method
+
     return(Z)
 }
